'use strict';

var config = require('@backstage/config');
var createFactRetriever = require('../service/fact/createFactRetriever.cjs.js');
require('@backstage/catalog-client');
require('lodash/isEmpty');
require('luxon');
require('../service/fact/factRetrievers/techdocsFactRetriever.cjs.js');
require('../service/persistence/persistenceContext.cjs.js');
require('express');
require('express-promise-router');
require('@backstage-community/plugin-tech-insights-common');
require('@backstage/catalog-model');
require('@backstage/errors');
require('@backstage/backend-defaults/rootHttpRouter');
require('@backstage/plugin-permission-common');
require('p-limit');

function readLifecycleConfig(config$1) {
  if (!config$1) {
    return void 0;
  }
  if (config$1.has("maxItems")) {
    return {
      maxItems: config$1.getNumber("maxItems")
    };
  }
  return {
    timeToLive: config.readDurationFromConfig(config$1.getConfig("timeToLive"))
  };
}
function readFactRetrieverConfig(config$1, name) {
  const factRetrieverConfig = config$1.getOptionalConfig(
    `techInsights.factRetrievers.${name}`
  );
  if (!factRetrieverConfig) {
    return void 0;
  }
  const cadence = factRetrieverConfig.getString("cadence");
  const initialDelay = factRetrieverConfig.has("initialDelay") ? config.readDurationFromConfig(factRetrieverConfig.getConfig("initialDelay")) : void 0;
  const lifecycle = readLifecycleConfig(
    factRetrieverConfig.getOptionalConfig("lifecycle")
  );
  const timeout = factRetrieverConfig.has("timeout") ? config.readDurationFromConfig(factRetrieverConfig.getConfig("timeout")) : void 0;
  return {
    cadence,
    initialDelay,
    lifecycle,
    timeout
  };
}
function createFactRetrieverRegistrationFromConfig(config, name, factRetriever) {
  const factRetrieverConfig = readFactRetrieverConfig(config, name);
  return factRetrieverConfig ? createFactRetriever.createFactRetrieverRegistration({
    ...factRetrieverConfig,
    factRetriever
  }) : void 0;
}

exports.createFactRetrieverRegistrationFromConfig = createFactRetrieverRegistrationFromConfig;
//# sourceMappingURL=config.cjs.js.map
