'use strict';

var FactRetrieverEngine = require('./fact/FactRetrieverEngine.cjs.js');
var FactRetrieverRegistry = require('./fact/FactRetrieverRegistry.cjs.js');
var persistenceContext = require('./persistence/persistenceContext.cjs.js');

const buildTechInsightsContext = async (options) => {
  const {
    factRetrievers,
    factCheckerFactory,
    config,
    discovery,
    database,
    logger,
    scheduler,
    auth,
    urlReader
  } = options;
  const buildFactRetrieverRegistry = () => {
    if (!options.factRetrieverRegistry) {
      if (!factRetrievers) {
        throw new Error(
          "Failed to build FactRetrieverRegistry because no factRetrievers found"
        );
      }
      return new FactRetrieverRegistry.DefaultFactRetrieverRegistry(factRetrievers);
    }
    return options.factRetrieverRegistry;
  };
  const factRetrieverRegistry = buildFactRetrieverRegistry();
  const persistenceContext$1 = options.persistenceContext ?? await persistenceContext.initializePersistenceContext(database, {
    logger
  });
  const factRetrieverEngine = await FactRetrieverEngine.DefaultFactRetrieverEngine.create({
    scheduler,
    repository: persistenceContext$1.techInsightsStore,
    factRetrieverRegistry,
    factRetrieverContext: {
      config,
      discovery,
      logger,
      auth,
      urlReader
    }
  });
  await factRetrieverEngine.schedule();
  if (factCheckerFactory) {
    const factChecker = factCheckerFactory.construct(
      persistenceContext$1.techInsightsStore
    );
    return {
      persistenceContext: persistenceContext$1,
      factChecker,
      factRetrieverEngine
    };
  }
  return {
    persistenceContext: persistenceContext$1,
    factRetrieverEngine
  };
};

exports.buildTechInsightsContext = buildTechInsightsContext;
//# sourceMappingURL=techInsightsContextBuilder.cjs.js.map
